// LED2.ino 02/07/2024 20:05:03 For Seeed XIAO nr52840
/*
  LED

  This example creates a Bluetooth? Low Energy peripheral with service that contains a
  characteristic to control an LED.

  You can use a generic Bluetooth? Low Energy central app, like LightBlue (iOS and Android) or
  nRF Connect (Android), to interact with the services and characteristics
  created in this sketch.
*/

#include <ArduinoBLE.h>

#define  BLE_UUID_SERVICE "9A48ECBA-2E92-082F-C079-9E75AAE428B1"
#define  BLE_UUID_CHARACTERISTIC "C8F88594-2217-0CA6-8F06-A4270B675D69"

         BLEService LEDService(BLE_UUID_SERVICE);
         BLEByteCharacteristic switchCharacteristic(BLE_UUID_CHARACTERISTIC, BLEWrite | BLENotify);

const int ledPin = LED_BUILTIN; // pin to use for the LED


void setup()
{
        byte manu[4] = {0x61, 0x63, 0x6D, 0x65};
        Serial.begin(9600);

        while (!Serial);

        // set LED pin to output mode
        pinMode(ledPin, OUTPUT);

         // begin initialization
         if (!BLE.begin())
         {
               Serial.println("starting BLE failed!");

               while (1);
         }

        // set advertised local name and service UUID:
        BLE.setLocalName("Viax");
        BLE.setAdvertisedService(LEDService);

        BLE.setManufacturerData(manu,4);

        // add service
        BLE.addService(LEDService);

        // add the characteristic to the service
        LEDService.addCharacteristic(switchCharacteristic);

        // set the initial value for the characeristic:
        //switchCharacteristic.writeValue(0);

        // start advertising
        BLE.advertise();

        Serial.println("BLE LED Peripheral");
}

void loop()
{
       // listen for Bluetooth? Low Energy peripherals to connect:
       BLEDevice central = BLE.central();

       // if a central is connected to peripheral:
       if (central) {
         Serial.print("Connected to central: ");
         // print the central's MAC address:
         Serial.println(central.address());

         // while the central is still connected to peripheral:
         while (central.connected())
         {
               // if the remote device wrote to the characteristic,
               // use the value to control the LED:
               if (switchCharacteristic.written())
               {
                     if (switchCharacteristic.value()) // any value other than 0
                     {
                       Serial.println("LED on");
                       digitalWrite(ledPin, HIGH);         // will turn the LED on
                     }
                     else
                     {                              // a 0 value
                       Serial.println(F("LED off"));
                       digitalWrite(ledPin, LOW);          // will turn the LED off
                     }
               }
         }

         // when the central disconnects, print it out:
         Serial.print(F("Disconnected from central: "));
         Serial.println(central.address());
       }
}
